==> foundation-0.0.45.tgz: package/Contexts/World/DVEFDataSync.js <==
import { DataSync } from "@divinevoxel/core/Interfaces/World/Data/DataSync.js";
import { DataSyncNode } from "@divinevoxel/core/Interfaces/World/Data/DataSyncNode.js";
//objects
import { WorldRegister } from "../../Data/World/WorldRegister.js";
import { ChunkDataTags, InitalizeChunkTags } from "./Data/Tags/ChunkTags.js";
import { ColumnDataTags, InitalizeColumnTags } from "./Data/Tags/ColumnTags.js";
import { InitalizeRegionTags, RegionDataTags, RegionHeaderTagManager, } from "./Data/Tags/RegionTags.js";
import { RegionHeaderRegister } from "../../Data/RegionHeaderRegister.js";
import { DimensionsRegister } from "../../Data/World/DimensionsRegister.js";
import { DVEFDataSyncIds } from "../../Data/Constants/DVEFDataSyncIds.js";
export class DVEFDataSync extends DataSync {
    constructor() {
        super();
        this.pipelines.init.regiser("FoundationDataSyncNode", (dataSync) => {
            InitalizeChunkTags();
            InitalizeColumnTags();
            InitalizeRegionTags();
            dataSync.worldDataTags.chunk.sync();
            dataSync.worldDataTags.column.sync();
            dataSync.worldDataTags.region.sync();
            return dataSync;
        });
    }
    worldDataTags = {
        chunk: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.ChunkTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => ChunkDataTags.initData,
            getUnSyncData: () => false,
        }, this),
        column: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.ColumnTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => ColumnDataTags.initData,
            getUnSyncData: () => false,
        }, this),
        region: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.RegionTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => [
                RegionDataTags.initData,
                RegionHeaderTagManager.initData,
            ],
            getUnSyncData: () => false,
        }, this),
    };
    worldData = {
        dimesnion: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Dimesnion,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const dimensionData = DimensionsRegister.getDimension(input);
                if (!dimensionData)
                    return false;
                return dimensionData;
            },
            getUnSyncData: () => true,
        }, this),
        chunk: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Chunk,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const chunk = WorldRegister.chunk.get(input);
                if (!chunk)
                    return false;
                return [input, chunk];
            },
            getUnSyncData: (input) => input,
        }, this),
        column: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Column,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const column = WorldRegister.column.get(input);
                if (!column)
                    return false;
                return [input, column];
            },
            getUnSyncData: (input) => input,
        }, this),
        region: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Region,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const region = WorldRegister.region.get(input);
                if (!region)
                    return false;
                return [input, region];
            },
            getUnSyncData: (input) => input,
        }, this),
        regionHeader: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.RegionHeader,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const regionHeader = RegionHeaderRegister.get(input);
                if (!regionHeader)
                    return false;
                return [input, regionHeader.buffer];
            },
            getUnSyncData: () => true,
        }, this),
    };
}

==> foundation-0.0.52.tgz: package/Contexts/World/DVEFDataSync.js <==
import { DataSync } from "@divinevoxel/core/Interfaces/World/Data/DataSync.js";
import { DataSyncNode } from "@divinevoxel/core/Interfaces/World/Data/DataSyncNode.js";
//objects
import { WorldRegister } from "../../Data/World/WorldRegister.js";
import { ChunkDataTags, InitalizeChunkTags } from "./Data/Tags/ChunkTags.js";
import { ColumnDataTags, InitalizeColumnTags } from "./Data/Tags/ColumnTags.js";
import { InitalizeRegionTags, RegionDataTags, RegionHeaderTagManager, } from "./Data/Tags/RegionTags.js";
import { RegionHeaderRegister } from "../../Data/RegionHeaderRegister.js";
import { DimensionsRegister } from "../../Data/World/DimensionsRegister.js";
import { DVEFDataSyncIds } from "../../Data/Constants/DVEFDataSyncIds.js";
export class DVEFDataSync extends DataSync {
    constructor() {
        super();
        this.pipelines.init.regiser("FoundationDataSyncNode", (dataSync) => {
            InitalizeChunkTags();
            InitalizeColumnTags();
            InitalizeRegionTags();
            dataSync.worldDataTags.chunk.sync();
            dataSync.worldDataTags.column.sync();
            dataSync.worldDataTags.region.sync();
            return dataSync;
        });
    }
    worldDataTags = {
        chunk: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.ChunkTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => ChunkDataTags.initData,
            getUnSyncData: () => false,
        }, this),
        column: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.ColumnTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => ColumnDataTags.initData,
            getUnSyncData: () => false,
        }, this),
        region: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.RegionTags,
            commCheck: (options) => options.worldDataTags,
            getSyncData: () => [
                RegionDataTags.initData,
                RegionHeaderTagManager.initData,
            ],
            getUnSyncData: () => false,
        }, this),
    };
    worldData = {
        dimesnion: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Dimesnion,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const dimensionData = DimensionsRegister.instance.getDimension(input);
                if (!dimensionData)
                    return false;
                return dimensionData;
            },
            getUnSyncData: () => true,
        }, this),
        chunk: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Chunk,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const chunk = WorldRegister.instance.chunk.get(input);
                if (!chunk)
                    return false;
                return [input, chunk];
            },
            getUnSyncData: (input) => input,
        }, this),
        column: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Column,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const column = WorldRegister.instance.column.get(input);
                if (!column)
                    return false;
                return [input, column];
            },
            getUnSyncData: (input) => input,
        }, this),
        region: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.Region,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const region = WorldRegister.instance.region.get(input);
                if (!region)
                    return false;
                return [input, region];
            },
            getUnSyncData: (input) => input,
        }, this),
        regionHeader: new DataSyncNode({
            dataSyncType: DVEFDataSyncIds.RegionHeader,
            commCheck: (options) => options.worldData,
            getSyncData: (input) => {
                const regionHeader = RegionHeaderRegister.get(input);
                if (!regionHeader)
                    return false;
                return [input, regionHeader.buffer];
            },
            getUnSyncData: () => true,
        }, this),
    };
}
